setwd("C:/Documents and Settings/John/My Documents//Tables Into Graphs_Main")

#TABLE 2 from Kaplan (2006)
#begin by create vectors for each column in table
var.names <- c("Issue\nConvergence\n(982)", "Competitiveness\n(CQ Ranking)\n(65)", 
    "Total Spending/\nCapita \n(65)", "Difference Spending/\nCapita\n(65)",
     "State VotingAge\nPop. (millions-ln) \n(65)", 
    "Percent\nNegative Ads\n(65)", "2000 Year\n(65)", "2002 Year\n(65)",
    "Consensual\nIssue\n(43)", "Issue\nOwned\n(43)", "Issue\nSalience\n(43)") 
mean.vec <- c(24.85, 1.54, 3.47, 1.12, 1.2, 21.38, .38, .32, .28, .49, 2.86)
sd.vec <- c(34.73, 1.2, 2.71, 1.32, .85, 16.84, .49, .47, .45, .51, 6.38)
min.vec <- c(0, 0, .28, .03, -.65, 0, 0, 0, 0,0, 0)
max.vec <- c(99.98, 3, 13.39, 9.26, 3.13, 54.96, 1, 1, 1, 1, 35.63)

#Divide into groups:
    #Binary
    #millions (+competitiveness)
    #percents (+issue salience)

#use points for mean, thick lines for +- 1 sd, thin lines for min-max
pdf("kaplan_fig.pdf", height = 6, width =8) #open pdf device
layout(rbind(c(1,2), c(3,3)),widths=c(3,3.1,2.6), respect = F) #since we are using unequal panel
    #sizes, we use layout command.  We create 2 panels on top and 1 bottom. We then manually
    #adjust widths so that each panel is approximately equal in width, after labeling is 
    #taken into account.
    
#layout.show(3) #can use this command to check results of layout command (but it must be commented out when creating PDF).

#Within each group: keep only vars from that group.  Then reorder.
#1st graph -- Binary vars
keep <- 7:10 #pull out only binary vars, which happen to be the 7th-10th vars in our vectors
#create vectors for each; could also use mean.vec[7:10] etc.
mean.vec.binary <-  mean.vec[keep] 
sd.vec.binary<- sd.vec[keep]
min.vec.binary <- min.vec[keep]
max.vec.binary <- max.vec[keep]
var.names.binary<-var.names[keep]

#order vectors by mean values, in descending order
mean.vec.binary.order <- sort(mean.vec.binary, decreasing = TRUE) #first sort by means
sd.vec.binary.order <- sd.vec.binary[order(mean.vec.binary, decreasing = TRUE)] #then sort other vectors by sorted mean variable
min.vec.binary.order <- min.vec.binary[order(mean.vec.binary, decreasing = TRUE)]
max.vec.binary.order <- max.vec.binary[order(mean.vec.binary, decreasing = TRUE)]
var.names.binary.order <- var.names.binary[order(mean.vec.binary, decreasing = TRUE)]

y.axis.binary <- c(length(mean.vec.binary):1)# descending so that R orders vars from top to bottom on y-axis
par(mar=c(3,7,3,1)) #adjust margins for  plot
plot(mean.vec.binary.order, y.axis.binary, type = "p", pch = 19, xlab="", ylab ="", #plot circular points; leave axis labels blank; we will fil in using axis command
    axes = F, xlim = c(min(min.vec.binary.order), max(max.vec.binary.order)), #turn off axes so we can use fine control; set min/max of x-label according to min and maximums of var
    ylim = c(min(y.axis.binary - .1), max(y.axis.binary + .1)), # increase y-axis min/max by .1 so there no points and lines don't run into top and bottom of panels
     main = "Binary Variables", xaxs="r") #add title; xaxs="i" uses internal axes, meaning axes are drawn right at xlim values 
box() #draw box around panel
axis(1, at = seq(0,1,by=.25), labels =  seq(0,1,by=.25), tick = T, #draw x-axis and labels, tick marks and labels every .25,
     cex.axis = .8, mgp = c(2,.5,0))#shrink axis-label size to .8, use mgp to place labels closer to tick marks
axis(2, at = y.axis.binary, label = var.names.binary.order, las = 1, tick = T,#draw y-axis and labels, las = 1 makes y-labels perpendicular to y-axis instead of parallel
    cex.axis =1, mgp = c(2,3,0), hadj=.5) # hadj =.5 uses center-alignment for y-label; need to adjust
        #2nd command in "mgp" to account for centering

#2nd graph -- Percents
keep <- c(1,6,11) #pull out percent variables
mean.vec.percents <-  mean.vec[keep]
sd.vec.percents<- sd.vec[keep]
min.vec.percents <- min.vec[keep]
max.vec.percents <- max.vec[keep]
var.names.percents<-var.names[keep]

mean.vec.percents.order <- sort(mean.vec.percents, decreasing = TRUE)#order by means, in descending order
sd.vec.percents.order <- sd.vec.percents[order(mean.vec.percents, decreasing = TRUE)] #then sort other vectors by sorted mean variable
min.vec.percents.order <- min.vec.percents[order(mean.vec.percents, decreasing = TRUE)]
max.vec.percents.order <- max.vec.percents[order(mean.vec.percents, decreasing = TRUE)]
var.names.percents.order <- var.names.percents[order(mean.vec.percents, decreasing = TRUE)]

y.axis.percents <- c(length(mean.vec.percents):1)# descending so that R orders vars from top to bottom on y-axis
par(mar=c(3,8,3,1)) #adjust margins for plot
plot(mean.vec.percents.order, y.axis.percents, type = "p", pch = 19, xlab="", ylab ="", #create plot with points
    axes = F, xlim = c(-12, 100),#turn off axes, manually set up x-axis limit based on inspection of the plot
    ylim = c(min(y.axis.percents - .1), max(y.axis.percents + .1)),# increase y-axis min/max by .1 so there no points and lines don't run into top and bottom of panels
     main = "Percentage Variables", xaxs="i")#add title; xaxs="i" uses internal axes, meaning axes are drawn right at xlim values 
box()#draw box around panel
segments((mean.vec.percents.order - sd.vec.percents.order), y.axis.percents, (mean.vec.percents.order + sd.vec.percents.order), y.axis.percents)#add lines connecting +/- 1 st.dev
segments(min.vec.percents.order, y.axis.percents, max.vec.percents.order, y.axis.percents, lty = 2)#add dotted lines (lty=2) connecting min to max
axis(1, at = seq(0,100,by=25), labels =  c(0,25,50,75,"100%"), tick = T, #draw x-axis and labels, tick marks and labels every 25%,
    cex.axis = .8, mgp = c(2,.5,0)) #shrink axis-label size to .8, use mgp to place labels closer to tick marks
axis(2, at = y.axis.percents, label = var.names.percents.order, las = 1, tick = T,  #draw y-axis and labels, las = 1 makes y-labels perpendicular to y-axis instead of parallel
    cex.axis =1, mgp = c(2,3.2,0), hadj=.5) # hadj =.5 uses center-alignment for y-label; need to adjust
        #2nd command in "mgp" to account for centering
    
#3rd graph --millions
keep <- c(2:5) #pull out millions variables
mean.vec.millions <-  mean.vec[keep]
sd.vec.millions<- sd.vec[keep]
min.vec.millions <- min.vec[keep]
max.vec.millions <- max.vec[keep]
var.names.millions<-var.names[keep]

mean.vec.millions.order <- sort(mean.vec.millions, decreasing = TRUE) #order by means, in descending order
sd.vec.millions.order <- sd.vec.millions[order(mean.vec.millions, decreasing = TRUE)] #then sort other vectors by sorted mean variable
min.vec.millions.order <- min.vec.millions[order(mean.vec.millions, decreasing = TRUE)]
max.vec.millions.order <- max.vec.millions[order(mean.vec.millions, decreasing = TRUE)]
var.names.millions.order <- var.names.millions[order(mean.vec.millions, decreasing = TRUE)]

y.axis.millions <- c(length(mean.vec.millions):1)# descending so that R orders vars from top to bottom on y-axis
par(mar=c(3,18,3,12)) #adjust margins for plot
plot(mean.vec.millions.order, y.axis.millions, type = "p", pch = 19, xlab="", ylab ="", #plot points
    axes = F, xlim = c(-1, 14),#turn off axes, manually set up x-axis limit based on inspection of the plot
    ylim = c(min(y.axis.millions - .1), max(y.axis.millions + .1)),# increase y-axis min/max by .1 so there no points and lines don't run into top and bottom of panels
     main = "Variables Measured in Millions", xaxs="i")#add title; xaxs="i" uses internal axes, meaning axes are drawn right at xlim values 
box()#draw box around panel
segments((mean.vec.millions.order - sd.vec.millions.order), y.axis.millions, (mean.vec.millions.order + sd.vec.millions.order), y.axis.millions)#line connecting +/- 1 st.dev
segments(min.vec.millions.order, y.axis.millions, max.vec.millions.order, y.axis.millions, lty = 2)#line connecting +/- 1 st.dev
axis(1, at = seq(0,14,by=2), labels =  seq(0,14,by=2), tick = T, las  = 1,#draw x-axis and labels, tick marks and labels every 2nd value,
    line =0, cex.axis = .8, mgp = c(2,.5,0)) #shrink axis-label size to .8, use mgp to place labels closer to tick marks
axis(2, at = y.axis.millions, label = var.names.millions, las = 1, tick = T, #draw y-axis and labels, las = 1 makes y-labels perpendicular to y-axis instead of parallel
    cex.axis =1, mgp = c(2,5,0), hadj=.5) # hadj =.5 uses center-alignment for y-label; need to adjust
        #2nd command in "mgp" to account for centering
    
dev.off()#turn pdf device off; file is now drawd in working directory.
